@@ -211,7 +211,7 @@ bool ListPlugins(const QString& libraryName = QString::fromLatin1(""))
 
         Plugin* const plugin = (*it)->plugin();
 
-        if (plugin == 0)
+        if (plugin == nullptr)
         {
             qDebug() << preSpace << QString::fromLatin1( "Plugin not loaded.");
             continue;
@@ -266,7 +266,7 @@ bool CallAction(const QString& actionText, const QString& libraryName = QString:
         // scan for the desired action:
         Plugin* const plugin = (*info)->plugin();
 
-        if (plugin == 0)
+        if (plugin == nullptr)
         {
             qDebug() << QString::fromLatin1("Plugin \"%1\" failed to load.").arg((*info)->library());
             continue;
@@ -324,7 +324,7 @@ int main(int argc, char* argv[])
     parser.addOption(QCommandLineOption(QStringList() << QLatin1String("l"),              QLatin1String("Library name of plugin to use"),             QLatin1String("library")));
     parser.addOption(QCommandLineOption(QStringList() << QLatin1String("a"),              QLatin1String("Action to call"),                            QLatin1String("action")));
     parser.addOption(QCommandLineOption(QStringList() << QLatin1String("i"),              QLatin1String("Selected images"),                           QLatin1String("selectedimages")));
-    parser.addOption(QCommandLineOption(QStringList() << QLatin1String("c"),              QLatin1String("Selected colections"),                       QLatin1String("selectedcollections")));
+    parser.addOption(QCommandLineOption(QStringList() << QLatin1String("c"),              QLatin1String("Selected collections"),                       QLatin1String("selectedcollections")));
     parser.addOption(QCommandLineOption(QStringList() << QLatin1String("allc"),           QLatin1String("All collections"),                           QLatin1String("allcollections")));
     parser.addOption(QCommandLineOption(QStringList() << QLatin1String("+[images]"),      QLatin1String("List of images")));
     parser.addOption(QCommandLineOption(QStringList() << QLatin1String("+[collections]"), QLatin1String("List of collections")));
@@ -332,7 +332,7 @@ int main(int argc, char* argv[])
 
     KipiInterface* const kipiInterface = new KipiInterface(&app);
 
-    PluginLoader* const loader = new PluginLoader(0);
+    PluginLoader* const loader = new PluginLoader(nullptr);
     loader->setInterface(kipiInterface);
     loader->init();
 
@@ -342,7 +342,7 @@ int main(int argc, char* argv[])
 
     // Determine which with list we start
 
-    QList<QUrl>* startList = 0;
+    QList<QUrl>* startList = nullptr;
 
     if (parser.isSet(QString::fromLatin1("i")))
     {
@@ -393,7 +393,7 @@ int main(int argc, char* argv[])
         }
         else
         {
-            if (startList == 0)
+            if (startList == nullptr)
             {
                 qCritical() << "StartList is null.\n"
                                "Please specify how the filenames you provided should be used.";
@@ -449,7 +449,7 @@ int main(int argc, char* argv[])
     {
         qCritical() << "No argument specified: either use --list,\n"
                        "or specify an action to be called.\n"
-                       "Exemple : ./kipicmd -w -lkipiplugin_kxmlhelloworld -a\"KXML Hello World Image...\" -i ~/Images/*";
+                       "Example : ./kipicmd -w -lkipiplugin_kxmlhelloworld -a\"KXML Hello World Image...\" -i ~/Images/*";
         return 0;
     }
 
